Skip to contents

Convert dates easily without specifying format. The format is identified automatically and converted to standard Year-month-day.

Usage

datR(data, vars)

Arguments

data

data frame

vars

vector of character vars to convert to date format

Value

the input data frame with correctly formatted date variables