Pick the closest value from a range in vector.
Usage
closR(x, vec = NULL, str, split = T)
Arguments
- x
Input number
- vec
vector to search for closest value. If NULL, provide str which vec should be created from
- str
Multiplier for the generic vector
- split
whether the tablet can be split
Value
Returns the dose closest to the estimated