tockR stops the clock and prints either a date/time or a time difference
Usage
tockR(format = "diff", start, digits = 2)
Arguments
- format
Whether date and time or a time difference should be returned
- digits
Number of digits on time difference
Value
Date/time or time difference since tickR()